@@ -7,14 +7,16 @@
 
 # NDN Imports
 from ndn.encoding import Component, TlvModel, UintField, BytesField, DecodeError
+# Custom Imports
+from .tlv import SVSyncTlvTypes
 
 # Class Type: a tlv structure for encoding
 # Class Purpose:
 #   hold all aspects of MetaData in a Model
 class MetaDataModel(TlvModel):
-    source = BytesField(198)
-    tseqno = UintField(199)
-    nopcks = UintField(200)
+    source = BytesField(SVSyncTlvTypes.META_SOURCE.value)
+    tseqno = UintField(SVSyncTlvTypes.META_TOTAL.value)
+    nopcks = UintField(SVSyncTlvTypes.META_NOPCKS.value)
 
 # Class Type: a API class
 # Class Purpose:
