@@ -8,27 +8,20 @@
 from __future__ import annotations
 
 # Basic Libraries
-from enum import Enum
 from struct import unpack_from
 from typing import List, Optional
 # NDN Imports
 from ndn.encoding import Component, TlvModel, BytesField, UintField
 from ndn.encoding import get_tl_num_size, write_tl_num, parse_tl_num
-
-# Class Type: an enumeration struct
-# Class Purpose:
-#   to differ tlv model types.
-class StateVectorModelTypes(Enum):
-    VECTOR = 201
-    KEY = 202
-    VALUE = 203
+# Custom Imports
+from .tlv import SVSyncTlvTypes
 
 # Class Type: a struct
 # Class Purpose:
 #   to hold info about a singular node within the vector.
 class StateVectorComponentModel(TlvModel):
-    nid = BytesField(StateVectorModelTypes.KEY.value)
-    seqno = UintField(StateVectorModelTypes.VALUE.value)
+    nid = BytesField(SVSyncTlvTypes.VECTOR_ENTRY.value)
+    seqno = UintField(SVSyncTlvTypes.SEQNO.value)
 
 # Class Type: an custom tlv model class
 # Class Purpose:
@@ -39,9 +32,9 @@ class StateVectorModel:
     def encode(self) -> bytearray:
         component_wires = [v.encode() for v in self.value]
         length = sum(len(w) for w in component_wires)
-        buf_len = length + get_tl_num_size(length) + get_tl_num_size(StateVectorModelTypes.VECTOR.value)
+        buf_len = length + get_tl_num_size(length) + get_tl_num_size(SVSyncTlvTypes.VECTOR.value)
         ret = bytearray(buf_len)
-        pos = write_tl_num(StateVectorModelTypes.VECTOR.value, ret)
+        pos = write_tl_num(SVSyncTlvTypes.VECTOR.value, ret)
         pos += write_tl_num(length, ret, pos)
         for w in component_wires:
             ret[pos:pos + len(w)] = w
@@ -51,7 +44,7 @@ class StateVectorModel:
     def parse(buf:Component) -> Optional[StateVectorModel]:
         # Verify the Type
         typ, pos = parse_tl_num(buf)
-        if typ != StateVectorModelTypes.VECTOR.value:
+        if typ != SVSyncTlvTypes.VECTOR.value:
             return None
         # Check the length
         length, l = parse_tl_num(buf, pos)
@@ -62,37 +55,37 @@ class StateVectorModel:
         ret:StateVectorModel = StateVectorModel([])
         ret.value = []
         while pos < len(buf):
-            # Node ID
+            # Entry ID
             typ, l = parse_tl_num(buf, pos)
             pos += l
-            if typ != StateVectorModelTypes.KEY.value:
+            if typ != SVSyncTlvTypes.VECTOR_ENTRY.value:
                 return None
             length, l = parse_tl_num(buf, pos)
             pos += l
-            node_id = buf[pos:pos + length]
+            entry = buf[pos:pos + length]
             pos += length
-            # Value
+            # Seqno
             typ, l = parse_tl_num(buf, pos)
             pos += l
-            if typ != StateVectorModelTypes.VALUE.value:
+            if typ != SVSyncTlvTypes.SEQNO.value:
                 return None
             length, l = parse_tl_num(buf, pos)
             pos += l
             if length == 1:
-                value = unpack_from('!B', buf, pos)[0]
+                seqno = unpack_from('!B', buf, pos)[0]
             elif length == 2:
-                value = unpack_from('!H', buf, pos)[0]
+                seqno = unpack_from('!H', buf, pos)[0]
             elif length == 4:
-                value = unpack_from('!I', buf, pos)[0]
+                seqno = unpack_from('!I', buf, pos)[0]
             elif length == 8:
-                value = unpack_from('!Q', buf, pos)[0]
+                seqno = unpack_from('!Q', buf, pos)[0]
             else:
                 return None
             pos += length
             # Append the component
             comp:StateVectorComponentModel = StateVectorComponentModel()
-            comp.nid = node_id
-            comp.seqno = value
+            comp.nid = entry
+            comp.seqno = seqno
             ret.value.append(comp)
         return ret
 
@@ -102,12 +95,14 @@ class StateVectorModel:
 class StateVector:
     def __init__(self, component:Component=None) -> None:
         self.vector:StateVectorModel = StateVectorModel([])
+        self.wire:Optional[bytes] = None
         if component:
             temp_vector:Optional[StateVectorModel] = StateVectorModel.parse(component)
             if temp_vector != None:
                 for i in temp_vector.value:
                     self.set(bytes(i.nid).decode(), i.seqno, True)
     def set(self, nid:str, seqno:int, oldData:bool=False) -> None:
+        self.wire = None
         index:Optional[int] = self.index(nid)
         if index == None:
             svc:StateVectorComponentModel = StateVectorComponentModel()
@@ -136,7 +131,9 @@ class StateVector:
     def to_str(self) -> str:
         return " ".join([( bytes(i.nid).decode() + ":" + str(i.seqno) ) for i in self.vector.value])
     def encode(self) -> bytes:
-        return self.vector.encode()
+        if self.wire == None:
+            self.wire = self.vector.encode()
+        return self.wire
     def keys(self) -> List[str]:
         return [bytes(i.nid).decode() for i in self.vector.value]
     def list(self) -> List[StateVectorComponentModel]:
