@@ -9,7 +9,7 @@
 from typing import Callable, Optional
 # NDN Imports
 from ndn.app import NDNApp
-from ndn.encoding import Name
+from ndn.encoding import Name, Component
 from ndn.storage import Storage
 # Custom Imports
 from .security import SecurityOptions
@@ -20,7 +20,7 @@ from .svs_base import SVSyncBase
 #   to allow the user to interact with SVS, fetch and publish.
 class SVSync(SVSyncBase):
     def __init__(self, app:NDNApp, groupPrefix:Name, nid:Name, updateCallback:Callable, storage:Optional[Storage]=None, securityOptions:Optional[SecurityOptions]=None) -> None:
-        preSyncPrefix, preDataPrefix = groupPrefix, nid + groupPrefix + Name.from_str("/data")
+        preSyncPrefix, preDataPrefix = groupPrefix + [Component.from_str("sync")], nid + groupPrefix + [Component.from_str("data")]
         super().__init__(app, preSyncPrefix, preDataPrefix, groupPrefix, nid, updateCallback, storage, securityOptions)
-    def getDataName(self, nid:Name, seqNum:int) -> Name:
-        return ( nid + self.groupPrefix + Name.from_str("/data") + Name.from_str(str(seqNum)) )
\ No newline at end of file
+    def getDataName(self, nid:Name, seqno:int) -> Name:
+        return ( nid + self.groupPrefix + [Component.from_str("data")] + Name.from_str(str(seqno)) )
\ No newline at end of file
