@@ -9,8 +9,7 @@
 from typing import Optional, Callable, Tuple
 # NDN Imports
 from ndn.app import NDNApp
-from ndn.encoding import Name, MetaInfo, InterestParam, BinaryStr, FormalName, SignatureType
-from ndn.encoding import make_data, parse_data
+from ndn.encoding import Name, MetaInfo, InterestParam, BinaryStr, FormalName, SignatureType, make_data, parse_data
 from ndn.types import InterestNack, InterestTimeout, InterestCanceled, ValidationFailure
 from ndn.storage import Storage, MemoryStorage
 # Custom Imports
@@ -23,8 +22,10 @@ from .security import SecurityOptions, SigningInfo, ValidatingInfo
 #   to derive different SVSync from.
 #   to allow the user to interact with SVS, fetch and publish.
 class SVSyncBase():
+    DATA_INTEREST_LIFETIME = 2000
+    DATA_PACKET_FRESHNESS = 10000
     def __init__(self, app:NDNApp, syncPrefix:Name, dataPrefix:Name, groupPrefix:Name, nid:Name, updateCallback:Callable, storage:Optional[Storage]=None, securityOptions:Optional[SecurityOptions]=None) -> None:
-        SVSyncLogger.info("SVSync: started svsync")
+        SVSyncLogger.info("SVSync: started an svsync type")
         self.app, self.syncPrefix, self.dataPrefix, self.groupPrefix, self.nid, self.updateCallback = app, syncPrefix, dataPrefix, groupPrefix, nid, updateCallback
         self.storage = MemoryStorage() if not storage else storage
         self.secOptions = securityOptions if securityOptions is not None else SecurityOptions(SigningInfo(SignatureType.DIGEST_SHA256), ValidatingInfo(ValidatingInfo.get_validator(SignatureType.DIGEST_SHA256)), SigningInfo(SignatureType.DIGEST_SHA256), [])
@@ -36,12 +37,12 @@ class SVSyncBase():
         if data_pkt:
             SVSyncLogger.info(f'SVSync: served data {Name.to_str(int_name)}')
             self.app.put_raw_packet(data_pkt)
-    async def _fetch(self, nid:Name, seqNum:int, retries:int=0) -> Tuple[Optional[bytes], Optional[BinaryStr]]:
-        name = self.getDataName(nid, seqNum)
+    async def _fetch(self, nid:Name, seqno:int, retries:int=0) -> Tuple[Optional[bytes], Optional[BinaryStr]]:
+        name = self.getDataName(nid, seqno)
         while retries+1 > 0:
             try:
                 SVSyncLogger.info(f'SVSync: fetching data {Name.to_str(name)}')
-                _, _, _, pkt = await self.app.express_interest(name, need_raw_packet=True, must_be_fresh=True, can_be_prefix=False, lifetime=6000)
+                _, _, _, pkt = await self.app.express_interest(name, need_raw_packet=True, must_be_fresh=True, can_be_prefix=False, lifetime=self.DATA_INTEREST_LIFETIME)
                 ex_int_name, meta_info, content, sig_ptrs = parse_data(pkt)
                 isValidated = await self.secOptions.validate(ex_int_name, sig_ptrs)
                 if not isValidated:
@@ -63,19 +64,19 @@ class SVSyncBase():
             if retries+1 > 0:
                 SVSyncLogger.info("SVSync: retrying fetching data")
         return (None, None)
-    async def fetchData(self, nid:Name, seqNum:int, retries:int=0) -> Optional[bytes]:
-        data, _ = await self._fetch(nid, seqNum, retries)
+    async def fetchData(self, nid:Name, seqno:int, retries:int=0) -> Optional[bytes]:
+        data, _ = await self._fetch(nid, seqno, retries)
         return data
-    async def fetchDataPacket(self, nid:Name, seqNum:int, retries:int=0) -> Optional[BinaryStr]:
-        _, pkt = await self._fetch(nid, seqNum, retries)
+    async def fetchDataPacket(self, nid:Name, seqno:int, retries:int=0) -> Optional[BinaryStr]:
+        _, pkt = await self._fetch(nid, seqno, retries)
         return pkt
     def publishData(self, data:bytes) -> None:
-        name = self.getDataName(self.nid, self.core.getSeqNum()+1)
-        data_packet = make_data(name, MetaInfo(freshness_period=5000), content=data, signer=self.secOptions.dataSig.signer)
+        name = self.getDataName(self.nid, self.core.getSeqno()+1)
+        data_packet = make_data(name, MetaInfo(freshness_period=self.DATA_PACKET_FRESHNESS), content=data, signer=self.secOptions.dataSig.signer)
         SVSyncLogger.info(f'SVSync: publishing data {Name.to_str(name)}')
         self.storage.put_packet(name, data_packet)
-        self.core.updateMyState(self.core.getSeqNum()+1)
+        self.core.updateMyState(self.core.getSeqno()+1)
     def getCore(self) -> SVSyncCore:
         return self.core
-    def getDataName(self, nid:Name, seqNum:int) -> Name:
+    def getDataName(self, nid:Name, seqno:int) -> Name:
         raise NotImplementedError
\ No newline at end of file
