@@ -24,15 +24,15 @@ from .svs_base import SVSyncBase
 class SVSyncShared(SVSyncBase):
     def __init__(self, app:NDNApp, groupPrefix:Name, nid:Name, updateCallback:Callable, cacheOthers:bool, storage:Optional[Storage]=None, securityOptions:Optional[SecurityOptions]=None) -> None:
         self.cacheOthers = cacheOthers
-        preDataPrefix = groupPrefix + [Component.from_str("d")] if self.cacheOthers else groupPrefix + [Component.from_str("d")] + nid
-        preSyncPrefix = groupPrefix + [Component.from_str("s")]
+        preDataPrefix = groupPrefix + [Component.from_str("data")] if self.cacheOthers else groupPrefix + [Component.from_str("data")] + nid
+        preSyncPrefix = groupPrefix + [Component.from_str("sync")]
         super().__init__(app, preSyncPrefix, preDataPrefix, groupPrefix, nid, updateCallback, storage, securityOptions)
-    async def _fetch(self, nid:Name, seqNum:int, retries:int=0) -> Tuple[Optional[bytes], Optional[BinaryStr]]:
-        name = self.getDataName(nid, seqNum)
+    async def _fetch(self, nid:Name, seqno:int, retries:int=0) -> Tuple[Optional[bytes], Optional[BinaryStr]]:
+        name = self.getDataName(nid, seqno)
         while retries+1 > 0:
             try:
                 SVSyncLogger.info(f'SVSync: fetching data {Name.to_str(name)}')
-                _, _, _, pkt = await self.app.express_interest(name, need_raw_packet=True, must_be_fresh=True, can_be_prefix=False, lifetime=6000)
+                _, _, _, pkt = await self.app.express_interest(name, need_raw_packet=True, must_be_fresh=True, can_be_prefix=False, lifetime=2000)
                 ex_int_name, meta_info, content, sig_ptrs = parse_data(pkt)
                 isValidated = await self.secOptions.validate(ex_int_name, sig_ptrs)
                 if not isValidated:
@@ -56,8 +56,8 @@ class SVSyncShared(SVSyncBase):
             if retries+1 > 0:
                 SVSyncLogger.info("SVSync: retrying fetching data")
         return (None, None)
-    def getDataName(self, nid:Name, seqNum:int) -> Name:
-        return (self.groupPrefix + [Component.from_str("d")] + nid + Name.from_str(str(seqNum)))
+    def getDataName(self, nid:Name, seqno:int) -> Name:
+        return (self.groupPrefix + [Component.from_str("data")] + nid + Name.from_str(str(seqno)))
     def serveDataPacket(datapkt:BinaryStr) -> None:
         name, _, content, _ = parse_data(datapkt)
         if content:
